@@ -34,11 +34,11 @@
 #include <stdio.h>
 #include <time.h>
 
-#define PSL_VERSION "0.17.0"
+#define PSL_VERSION "0.19.1"
 #define PSL_VERSION_MAJOR 0
-#define PSL_VERSION_MINOR 17
-#define PSL_VERSION_PATCH 0
-#define PSL_VERSION_NUMBER 0x001100
+#define PSL_VERSION_MINOR 19
+#define PSL_VERSION_PATCH 1
+#define PSL_VERSION_NUMBER 0x001301
 
 #ifdef  __cplusplus
 extern "C" {
@@ -79,6 +79,10 @@ typedef struct _psl_ctx_st psl_ctx_t;
 void
 	psl_free(psl_ctx_t *psl);
 
+/* frees memory allocated by libpsl routines */
+void
+	psl_free_string(char *str);
+
 /* loads PSL data from file */
 psl_ctx_t *
 	psl_load_file(const char *fname);
@@ -155,7 +159,7 @@ const char *
 int
 	psl_check_version_number(int version);
 
-/* returns wether the built-in data is outdated or not */
+/* returns whether the built-in data is outdated or not */
 int
 	psl_builtin_outdated(void);
 
